Stan Math Library: stan/math/fwd/scal/fun/tan.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

tan.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_TAN_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_TAN_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T>
12 inline
13 fvar<T>
14 tan(const fvar<T>& x) {
15 using std::cos;
16 using std::tan;
17 return fvar<T>(tan(x.val_), x.d_ / (cos(x.val_) * cos(x.val_)));
18 }
19 }
20 }
21 #endif
stan::math::cos
fvar< T > cos(const fvar< T > &x)
Definition: cos.hpp:13
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::tan
fvar< T > tan(const fvar< T > &x)
Definition: tan.hpp:14
stan::math::tan
var tan(const var &a)
Return the tangent of a radian-scaled variable (cmath).
Definition: tan.hpp:49
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.